/* $Id: types.h,v 1.4 1999/02/23 11:43:22 martin Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __GLIBTOP_TYPES_H__
#define __GLIBTOP_TYPES_H__

BEGIN_LIBGTOP_DECLS

#define GLIBTOP_TYPE_LONG	1
#define GLIBTOP_TYPE_ULONG	2
#define GLIBTOP_TYPE_DOUBLE	3
#define GLIBTOP_TYPE_INT	4
#define GLIBTOP_TYPE_CHAR	5
#define GLIBTOP_TYPE_STRING	6

END_LIBGTOP_DECLS

#endif
